==> smallads-2.0.0-rc2.tar.gz: smallads/src/Form/SmalladEdit.php <==
<?php

namespace Drupal\smallads\Form;

use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\smallads\Entity\SmalladInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Datetime\DateFormatter;
use Drupal\Component\Datetime\TimeInterface;

/**
 * Form to create/edit a smallad entity.
 */
class SmalladEdit extends ContentEntityForm {

  /**
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * @var \Symfony\Component\HttpFoundation\ParameterBag
   */
  protected $params;

  /**
   * @var DateFormatter
   */
  protected $dateFormatter;

  /**
   * Constructs a SmalladEdit object.
   */
  public function __construct($entity_repository, $entity_type_bundle_info, TimeInterface $time, RouteMatchInterface $routeMatch, RequestStack $requestStack, DateFormatter $date_formatter) {
    parent::__construct($entity_repository, $entity_type_bundle_info, $time);
    $this->routeMatch = $routeMatch;
    $this->params = $requestStack->getCurrentRequest()->query;
    $this->dateFormatter = $date_formatter;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('current_route_match'),
      $container->get('request_stack'),
      $container->get('date.formatter')
    );
  }

  /**
   * Overrides Drupal\Core\Entity\ContentEntityForm::form().
   *
   * @todo set the min and max dates on $this->entity->expires - but how?
   */
  public function form(array $form, FormStateInterface $form_state) {
    if ($this->params->has('title')) {
      $this->entity->title->value = $this->params->get('title');
      // can't remember why this was necessary.
      $form['#action'] = '/ad/add/'.$this->entity->bundle();
    }
    $form = parent::form($form, $form_state);

    if ($this->entity->isNew() && $this->routeMatch->getParameter('taxonomy_term')) {
      $form['type'] = [
        '#type' => 'value',
        '#value' => $this->routeMatch->getParameter('taxonomy_term'),
      ];
    }

    // Move the scope and expires widgets into one details field.
    $form['published'] = [
      '#title' => $this->t('Visibility'),
      '#description' => $this->t("When the ad expires, the scope reverts to 'Just you'."),
      '#type' => 'details',
      '#open' => $this->entity->scope->value > 0,
      '#weight' => 25,
    ];

    $form['published']['scope'] = $form['scope'];
    unset($form['scope']);

    if (isset($form['expires'])) {
      $form['published']['expires'] = $form['expires'];
      unset($form['expires']);
    }
    $form['uid']['widget'][0]['target_id']['#access'] = $this->currentUser()->hasPermission('edit all smallads');
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $this->entity = parent::validateForm($form, $form_state);
    // Warn the user about the expiry date.
    if ($this->entity->expires->value - REQUEST_TIME > 0) {// Expires in the future.
      if ($this->entity->scope->value == SmalladInterface::SCOPE_PRIVATE) {
        $message = $this->t('If the expiry date is after now, the scope must not be private');
        $form_state->setErrorByName('scope', $message);
      }
    }
    else {// Expires in the past.
      if ($this->entity->scope->value != SmalladInterface::SCOPE_PRIVATE) {
        $message = $this->t('If the article is to be visible, the expiry must be AFTER now.');
        $form_state->setErrorByName('scope', $message);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $now = $this->time->getRequestTime();
    if ($this->entity->expires->value > $now) {
      $date = date('d-M-Y', $this->entity->expires->value);
      $midnight = strtotime($date);
      // Notify user of expiry date
      $this->messenger()->addStatus(
        $this->t(
          'Your @ad_type will expire in @interval.',
          [
            '@ad_type' => $this->entity->type->entity->label(),
            '@interval' => $this->dateFormatter->formatInterval($midnight - $now, 2)
          ]
        )
      );
    }
    else {
      // Set the scope of the ad to the member only the ad because the date was set to before now.
      $this->entity->expire();
      $this->messenger()->addStatus(
        t(
          'This @ad_type is invisible because it expired on @date',
          [
            '@ad_type' => $this->entity->type->entity->label(),
            '@date' => $this->dateFormatter->format($this->entity->expires->value)
          ]
        ),
        'warning'
      );
    }
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    parent::save($form, $form_state);
    $form_state->setRedirect('entity.smallad.canonical', ['smallad' => $this->entity->id()]);
  }

}

==> smallads-2.0.1.tar.gz: smallads/src/Form/SmalladEdit.php <==
<?php

namespace Drupal\smallads\Form;

use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\smallads\Entity\SmalladInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Datetime\DateFormatter;
use Drupal\Component\Datetime\TimeInterface;

/**
 * Form to create/edit a smallad entity.
 */
class SmalladEdit extends ContentEntityForm {

  /**
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * @var \Symfony\Component\HttpFoundation\ParameterBag
   */
  protected $params;

  /**
   * @var DateFormatter
   */
  protected $dateFormatter;

  /**
   * Constructs a SmalladEdit object.
   */
  public function __construct($entity_repository, $entity_type_bundle_info, TimeInterface $time, RouteMatchInterface $routeMatch, RequestStack $requestStack, DateFormatter $date_formatter) {
    parent::__construct($entity_repository, $entity_type_bundle_info, $time);
    $this->routeMatch = $routeMatch;
    $this->params = $requestStack->getCurrentRequest()->query;
    $this->dateFormatter = $date_formatter;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('current_route_match'),
      $container->get('request_stack'),
      $container->get('date.formatter')
    );
  }

  /**
   * Overrides Drupal\Core\Entity\ContentEntityForm::form().
   *
   * @todo set the min and max dates on $this->entity->expires - but how?
   */
  public function form(array $form, FormStateInterface $form_state) {
    if ($this->params->has('title')) {
      $this->entity->title->value = $this->params->get('title');
      // can't remember why this was necessary.
      $form['#action'] = '/ad/add/'.$this->entity->bundle();
    }
    $form = parent::form($form, $form_state);

    if ($this->entity->isNew() && $this->routeMatch->getParameter('taxonomy_term')) {
      $form['type'] = [
        '#type' => 'value',
        '#value' => $this->routeMatch->getParameter('taxonomy_term'),
      ];
    }
    // Move the scope widget into the expires fieldset.
    $form['scope']['#theme'] = 'smallad_scope_widget';
    $form['scope']['#weight'] = -1;
    $form['expires']['widget'][0]['scope'] = $form['scope'];
    unset($form['scope']);
    $form['uid']['widget'][0]['target_id']['#access'] = $this->currentUser()->hasPermission('edit all smallads');
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $this->entity = parent::validateForm($form, $form_state);
    $midnight = strtotime(date('d-M-Y', strtotime($this->entity->expires->value)));
    $scope_is_private = $this->entity->scope->value == SmalladInterface::SCOPE_PRIVATE;
    $expires_later = $midnight > $this->time->getRequestTime();
    // Warn the user about the expiry date.
    if ($scope_is_private and $expires_later) {
      $message = $this->t('If the expiry date is after now, the scope must not be private');
      $form_state->setErrorByName('scope', $message);
    }
    elseif (!$scope_is_private and !$expires_later) {
      $message = $this->t('If the article is to be visible, the expiry must be AFTER now.');
      $form_state->setErrorByName('scope', $message);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $now = $this->time->getRequestTime();
    // Convert the expiry time to the start of the same day.
    $midnight = strtotime(date('d-M-Y', strtotime($this->entity->expires->value)));
    if ($midnight >= $now) {
      // Notify user of expiry date
      $this->messenger()->addStatus(
        $this->t(
          'Your @ad_type will expire in @interval.',
          [
            '@ad_type' => $this->entity->type->entity->label(),
            '@interval' => $this->dateFormatter->formatInterval($midnight - $now, 2)
          ]
        )
      );
    }
    elseif ($midnight < $now) {
      // Set the scope of the ad to the member only the ad because the date was set to before now.
      $this->entity->expire();
      $this->messenger()->addStatus(
        t(
          'This @ad_type is hidden because the expiry date is in the past.',
          [
            '@ad_type' => $this->entity->type->entity->label()
          ]
        ),
        'warning'
      );
    }
    if ($this->entity->isNew()) {
      // set the owner's default scope to the same scope as this
      \Drupal::service('user.data')->set(
        'smallads',
        $this->entity->getOwnerId(),
        'defaultscope',
        $form_state->getValue('scope')
      );
    }
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    parent::save($form, $form_state);
    $form_state->setRedirect('entity.smallad.canonical', ['smallad' => $this->entity->id()]);
  }

}
